sqlobject.sresults module — SQLObject 3.9.1 documentation

# sqlobject.sresults module

class `sqlobject.sresults.` `SelectResults`(sourceClass, clause, clauseTables=None, **ops)

  Bases: `object`

  `IterationClass`

    alias of `sqlobject.dbconnection.Iteration`

  `accumulate`(*expressions)

    Use accumulate expression(s) to select result using another SQL select through current connection. Return the accumulate result

  `accumulateMany`(*attributes)

    Making the expressions for count/sum/min/max/avg of a given select result attributes. attributes must be a list/tuple of pairs (func_name, attribute); attribute can be a column name (like ‘a_column’) or a dot-q attribute (like Table.q.aColumn)

  `accumulateOne`(func_name, attribute)

    Making the sum/min/max/avg of a given select result attribute. attribute can be a column name (like ‘a_column’) or a dot-q attribute (like Table.q.aColumn)

  `avg`(attribute)
  `clone`(**newOps)
  `connection`(conn)
  `count`()

    Counting elements of current select results

  `distinct`()
  `filter`(filter_clause)
  `getOne`(default=<class 'sqlobject.sqlbuilder.NoDefault'>)

    If a query is expected to only return a single value, using `.getOne()` will return just that value.

    If not results are found, `SQLObjectNotFound` will be raised, unless you pass in a default value (like `.getOne(None)`).

    If more than one result is returned, `SQLObjectIntegrityError` will be raised.

  `lazyColumns`(value)
  `lazyIter`()

    Returns an iterator that will lazily pull rows out of the database and return SQLObject instances

  `limit`(limit)
  `max`(attribute)
  `min`(attribute)
  `newClause`(new_clause)
  `orderBy`(orderBy)
  `queryForSelect`()
  `reversed`()
  `sum`(attribute)
  property `throughTo`